==> speech-analytic-testing_3.5.4_database.tar.gz: database/mssql/procedures/SaveAuditorEvaluationPlan.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[SaveAuditorEvaluationPlan] (
	@Instance Varchar(50) = NULL, 				
	@IdEvaluationPlan Varchar(50) = NULL,
	@IdAuditor Varchar(50) = NULL,				
	@IdInteraction Varchar(250) = NULL,
	@InteractionType varchar(50) = NULL,	
	@InteractionDate Datetime = NULL,
	@InteractionDateEnd Datetime = NULL,	
	@InteractionDuration numeric(8) = NULL,
	@IdAgent varchar(50) = NULL,
	@idCampaign varchar(50) = NULL,
	@InteractionDispositionCode varchar(50) = NULL,
	@InteractionOrigin varchar(50) = NULL,
	@InteractionFormat varchar(20) = NULL,
	@ContactId varchar(50) = NULL,
	@LastModifiedByUserId Varchar(100) = NULL,
	@ContactAddress varchar(300) = NULL,
	@ContactName varchar(300) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
	DECLARE @ID INT = 0;

	-- Verificamos si existen un registros con las datos recibidos
	SELECT @ID = COUNT([Instance])
		FROM [AuditorEvaluationPlan] AEP (NOLOCK)
		WHERE AEP.[Instance] = @Instance
			AND AEP.[IdEvaluationPlan] = @IdEvaluationPlan
			AND AEP.[IdAuditor] = @IdAuditor
			AND AEP.[IdInteraction] = @IdInteraction
			AND AEP.[IdAgent] = @IdAgent
			AND AEP.[InteractionType] = @InteractionType

	-- Si existe, actualizamos dicho registro
	IF @ID > 0
		BEGIN
			UPDATE [AuditorEvaluationPlan]
				SET [InteractionOrigin] = @InteractionOrigin,
					[InteractionFormat] = @InteractionFormat,
					[ContactId] = [ContactId],
					[LastModifiedDate] = GETUTCDATE(),
					[TimeStamp] = GETUTCDATE()
				WHERE [Instance] = @Instance
					AND [IdEvaluationPlan] = @IdEvaluationPlan
					AND [IdAuditor] = @IdAuditor
					AND [IdInteraction] = @IdInteraction
					AND [IdAgent] = @IdAgent
					AND [InteractionType] = @InteractionType
		END
	-- Si no existe lo insertamos
	ELSE 
		BEGIN
			INSERT INTO [AuditorEvaluationPlan] (
				[Instance], [IdEvaluationPlan], [IdAuditor],
				[IdInteraction], [InteractionType], [InteractionDate],
				[InteractionDateEnd], [ManagementResult], [InteractionOrigin], 
				[IdAgent], [idCampaign], [InteractionDuration],
				[InteractionFormat], [ContactId], [TimeStamp], 
				[Completed], [Score], [LastModifiedByUserId],
				[Status], [StatusDescription],[ContactAddress],[ContactName]
				)
			VALUES (
				@Instance, @IdEvaluationPlan, @IdAuditor,
				@IdInteraction, @InteractionType, @InteractionDate, 
				@InteractionDateEnd, @InteractionDispositionCode, @InteractionOrigin,
				@IdAgent, @IdCampaign, @InteractionDuration,
				@InteractionFormat, @ContactId, GETUTCDATE(), 
				0, 0, @LastModifiedByUserId,
				1, 'NEW',@ContactAddress,@ContactName
			)
		END
	
    SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/SaveAuditorEvaluationPlan.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveAuditorEvaluationPlan] (
	@Instance Varchar(50) = NULL, 				
	@IdEvaluationPlan Varchar(50) = NULL,
	@IdAuditor Varchar(50) = NULL,				
	@IdInteraction Varchar(250) = NULL,
	@InteractionType varchar(50) = NULL,	
	@InteractionDate Datetime = NULL,
	@InteractionDateEnd Datetime = NULL,	
	@InteractionDuration numeric(8) = NULL,
	@IdAgent varchar(50) = NULL,
	@idCampaign varchar(50) = NULL,
	@InteractionDispositionCode varchar(50) = NULL,
	@InteractionOrigin varchar(50) = NULL,
	@InteractionFormat varchar(20) = NULL,
	@ContactId varchar(50) = NULL,
	@LastModifiedByUserId Varchar(100) = NULL,
	@ContactAddress varchar(300) = NULL,
	@ContactName varchar(300) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
	DECLARE @ID INT = 0;

	-- Verificamos si existen un registros con las datos recibidos
	SELECT @ID = COUNT([Instance])
		FROM [AuditorEvaluationPlan] AEP (NOLOCK)
		WHERE AEP.[Instance] = @Instance
			AND AEP.[IdEvaluationPlan] = @IdEvaluationPlan
			AND AEP.[IdAuditor] = @IdAuditor
			AND AEP.[IdInteraction] = @IdInteraction
			AND AEP.[IdAgent] = @IdAgent
			AND AEP.[InteractionType] = @InteractionType

	-- Si existe, actualizamos dicho registro
	IF @ID > 0
		BEGIN
			UPDATE [AuditorEvaluationPlan]
				SET [InteractionOrigin] = @InteractionOrigin,
					[InteractionFormat] = @InteractionFormat,
					[ContactId] = [ContactId],
					[LastModifiedDate] = GETUTCDATE(),
					[TimeStamp] = GETUTCDATE()
				WHERE [Instance] = @Instance
					AND [IdEvaluationPlan] = @IdEvaluationPlan
					AND [IdAuditor] = @IdAuditor
					AND [IdInteraction] = @IdInteraction
					AND [IdAgent] = @IdAgent
					AND [InteractionType] = @InteractionType
		END
	-- Si no existe lo insertamos
	ELSE 
		BEGIN
			INSERT INTO [AuditorEvaluationPlan] (
				[Instance], [IdEvaluationPlan], [IdAuditor],
				[IdInteraction], [InteractionType], [InteractionDate],
				[InteractionDateEnd], [ManagementResult], [InteractionOrigin], 
				[IdAgent], [idCampaign], [InteractionDuration],
				[InteractionFormat], [ContactId], [TimeStamp], 
				[Completed], [Score], [CreatedDate],
				[CreatedByUserId], [LastModifiedByUserId], [Status], 
				[StatusDescription], [ContactAddress], [ContactName]
				)
			VALUES (
				@Instance, @IdEvaluationPlan, @IdAuditor,
				@IdInteraction, @InteractionType, @InteractionDate, 
				@InteractionDateEnd, @InteractionDispositionCode, @InteractionOrigin,
				@IdAgent, @IdCampaign, @InteractionDuration,
				@InteractionFormat, @ContactId, GETUTCDATE(), 
				0, 0, GETUTCDATE(),
				@LastModifiedByUserId, @LastModifiedByUserId, 1, 
				'NEW',@ContactAddress,@ContactName
			)
		END
	
    SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
